Learn R Programming

Ricetl (version 0.2.5.1)

id2gender: Extraction Gender

Description

Extraction of gender in the resident identity cards of People's Republic of China.

Usage

id2gender(x,fillna=NA)

Arguments

x

A vector containing 18 Bit ID numbers,id2age.

fillna

The filling value of the missing value,the default value is NA,id2age.

Value

Return 'F' means that the corresponding identity card for female citizens,'M' means male.

Examples

Run this code
# NOT RUN {
library(Ricetl)
x <- c('654003198111200241','341881197709275718',
'340503199401248097','469030199406204103','5111001')
id2gender(x)
id2gender(x,fillna=25)

# }

Run the code above in your browser using DataLab