Learn R Programming

Ricetl (version 0.2.5.1)

id_card6: Data Set for Address Correspondence

Description

The form of the corresponding relationship between the first six places of the ID card and the address of the household registration.

Usage

data(id_card6)

Arguments

Examples

Run this code
# NOT RUN {
library(Ricetl)
data(id_card6)
# }

Run the code above in your browser using DataLab