powered by
Extraction of gender in the resident identity cards of People's Republic of China.
id2gender(x,fillna=NA)
A vector containing 18 Bit ID numbers,id2age.
The filling value of the missing value,the default value is NA,id2age.
Return 'F' means that the corresponding identity card for female citizens,'M' means male.
# NOT RUN { library(Ricetl) x <- c('654003198111200241','341881197709275718', '340503199401248097','469030199406204103','5111001') id2gender(x) id2gender(x,fillna=25) # }
Run the code above in your browser using DataLab