powered by
The form of the corresponding relationship between the first six places of the ID card and the address of the household registration.
data(id_card6)
# NOT RUN { library(Ricetl) data(id_card6) # }
Run the code above in your browser using DataLab